@@ -1,4 +1,4 @@
-# Copyright 2022 Google LLC.
+# Copyright 2023 Google LLC.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@ from unittest import mock
 
 from absl.testing import absltest
 from absl.testing import parameterized
+import jax
 import jax.numpy as jnp
 import numpy as np
 
@@ -80,7 +81,7 @@ class OptimizeMediaTest(parameterized.TestCase):
         geo_ratio=geo_ratio,
         seed=10)
 
-    self.assertIsInstance(kpi_predicted, jnp.DeviceArray)
+    self.assertIsInstance(kpi_predicted, jax.Array)
     self.assertLessEqual(kpi_predicted, 0)
     self.assertEqual(kpi_predicted.shape, ())
 
@@ -288,9 +289,47 @@ class OptimizeMediaTest(parameterized.TestCase):
         target_scaler=None,
         media_scaler=media_scaler)
     self.assertLen(results, expected_len)
-    self.assertIsInstance(results[1], jnp.DeviceArray)
-    self.assertIsInstance(results[2], jnp.DeviceArray)
+    self.assertIsInstance(results[1], jax.Array)
+    self.assertIsInstance(results[2], jax.Array)
 
+  @parameterized.named_parameters([
+      dict(
+          testcase_name="national_prices",
+          model_name="national_mmm",
+          prices=np.array([1., 0.8, 1.2, 1.5, 0.5]),
+      ),
+      dict(
+          testcase_name="national_ones",
+          model_name="national_mmm",
+          prices=np.ones(5),
+      ),
+      dict(
+          testcase_name="geo_prices",
+          model_name="geo_mmm",
+          prices=np.array([1., 0.8, 1.2, 1.5, 0.5]),
+      ),
+      dict(
+          testcase_name="geo_ones",
+          model_name="geo_mmm",
+          prices=np.ones(5),
+      ),
+  ])
+  def test_generate_starting_values_calculates_correct_values(
+      self, model_name, prices):
+    mmm = getattr(self, model_name)
+    n_time_periods = 10
+    budget = mmm.n_media_channels * n_time_periods
+    starting_values = optimize_media._generate_starting_values(
+        n_time_periods=10,
+        media_scaler=None,
+        media=mmm.media,
+        budget=budget,
+        prices=prices,
+    )
+
+    # Given that data is all ones, starting values will be equal to prices.
+    np.testing.assert_array_almost_equal(
+        starting_values, jnp.repeat(n_time_periods, repeats=5))
 
 if __name__ == "__main__":
   absltest.main()
